@@ -1,5 +1,3 @@
-# -*- coding: utf-8 -*-
-#
 # RERO Invenio Base
 # Copyright (C) 2022 RERO.
 # Copyright (C) 2022 UCLouvain.
@@ -20,4 +18,4 @@
 
 from rero_invenio_base.modules.export.proxies import current_export
 
-__all__ = ('current_export',)
+__all__ = ("current_export",)
